/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.column;

import org.opengion.fukurou.util.TagBuffer;
import org.opengion.hayabusa.db.AbstractRenderer;
import org.opengion.hayabusa.db.CellRenderer;
import org.opengion.hayabusa.db.DBColumn;

/**
 * LABEL レンデラーは、カラムの値を#FFFFFFの色として表示する場合に
 * 使用するクラスです。
 * #FFFFFFのように#付き7桁のデータで設定して下さい。
 *
 *  カラムの表示に必要な属性は, DBColumn オブジェクト より取り出します。
 * このクラスは、DBColumn オブジェクト毎に１つ作成されます。
 *
 * @og.group データ表示
 * 
 * @og.rev 5.5.4.0 新規作成
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class Renderer_COLOR extends AbstractRenderer {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "4.0.0 (2005/08/31)" ;

	private static final CellRenderer dbCell = new Renderer_COLOR() ;
	
	private final TagBuffer	tagBuffer = new TagBuffer();

	/**
	 * 各オブジェクトから自分のインスタンスを返します。
	 * 自分自身をキャッシュするのか、新たに作成するのかは、各サブクラスの実装に
	 * まかされます。
	 *
	 *
	 * @param   clm DBColumn オブジェクト
	 * @return  CellRenderer オブジェクト
	 */
	public CellRenderer newInstance( final DBColumn clm ) {
		return dbCell;
	}
	
	/**
	 * データの表示用文字列を返します。
	 *
	 * @param   value String
	 * @return  データの表示用文字列
	 */
	public String getValue( final String value ) {

		TagBuffer tag = new TagBuffer( "input" );
		tag.add( "readonly", "readonly" );
		tag.add( "style"   , "background-color:"+value+"; color:"+value+";" );
		tag.add( tagBuffer.makeTag() );

		return tag.makeTag();
	}

	/**
	 * データの表示用文字列を返します。
	 *
	 * @param   row   int 行番号
	 * @param   value String
	 * @return  データ表示用の文字列
	 */
	public String getValue( final int row,final String value ) {

		TagBuffer tag = new TagBuffer( "input" );
		tag.add( "readonly", "readonly" );
		tag.add( "style"   , "background-color:"+value+"; color:"+value+";" );
		tag.add( tagBuffer.makeTag() );

		return tag.makeTag( row,value );
	}
}
